#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="m1k1o/neko:firefox"
}

do_install_detail() {
  local config=`uci get neko.@neko[0].config_path 2>/dev/null`
  local port=`uci get neko.@neko[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get neko.@neko[0].image_name 2>/dev/null`
  local username=`uci get neko.@neko[0].username 2>/dev/null`
  local password=`uci get neko.@neko[0].password 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=8281
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=m1k1o/neko:firefox

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: "3.4"
services:
  neko:
    image: $IMAGE_NAME
    restart: "unless-stopped"
    shm_size: "2gb"
    ports:
      - "$port:8080"
      - "52000-52005:52000-52005/udp"
    environment:
      NEKO_SCREEN: '1920x1080@30'
      NEKO_PASSWORD: meowmix
      NEKO_PASSWORD_ADMIN: ${GEN_PASS}
      NEKO_EPR: 52000-52005
      NEKO_NAT1TO1: $config
    labels:
      plugsy.name: "neko"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/entypo/Cat"
      plugsy.link: "http://$config:$port"
EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$config:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

  echo "Your Neko admin password is: " $GEN_PASS
  echo "The default password for viewers is: meowmix"

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install neko"
  echo "      upgrade                Upgrade neko"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart neko"
  echo "      status                 neko status"
  echo "      port                   neko port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f neko
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} neko
  ;;
  "status")
    docker ps --all -f 'name=neko' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=neko' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
